\name{eval.match}
\alias{eval.match}
\title{Calculates several one dimensional imbalance measures}
\description{
Calculates several one dimensional imbalance measures for the original
and matched data sets}
\usage{
eval.match(group, data, drop=NULL, breaks = NULL, weights)
}
\arguments{
 \item{group}{the group variable}
  \item{data}{the data}
  \item{drop}{a vector of variable names in the data frame to ignore}
  \item{breaks}{a list of vectors of cutpoints used to calculate L1 measure. See Details.}
  \item{weights}{weights}
}
\details{
This function calculate several imbalance measures.
For numeric variables the difference in means (under the column \code{statistics}, 
the difference in quantiles and the L1
measure is calculated. For categorical variables the L1 measure and the 
Chi-squared distance (under column \code{statistics}) is calculated.
Column \code{type} reports either \code{(diff)} or \code{(Chi2)} according
to the type of statistic being calculated.


If the \code{breaks} are not specified, the same approach as in 
\code{\link{cem}} is used.  Please refer to \code{\link{cem}} help
page. In this case, breaks are used to calculate the L1 measure.

This function also calculate the global L1 imbalance measure. 
If \code{breaks} is missing, the default rule to calculate cutpoints
is the Scott's rule. 
See \code{\link{L1.meas}} help page for details.  
}
\value{
  An object og class \code{eval.match} which is a list with the following
  two elements
  \item{tab}{Table of imbalance measures}
  \item{L1}{The global L1 measure of imbalance}
}
\references{Stefano Iacus, Gary King, Giuseppe Porro, ``Matching for
  Casual Inference Without Balance Checking,''
  http://gking.harvard.edu/files/abs/cem-abs.shtml}
\author{Stefano Iacus, Gary King, and Giuseppe Porro}
  \examples{ data(LL)

mybr = list(re74=seq(0, 40000, by=5000), 
 re75 = seq(0, 40000, by=5000),
 age = seq(15, 55, by=5),
 education = 3:16)

todrop <- c("treated","re78")
   
L1.meas(LL$treated, LL, drop=todrop, breaks=mybr)
eval.match(LL$treated, LL, drop=todrop, breaks=mybr)

# cem match: automatic bin choice
mat <- cem(treatment="treated", data=LL, drop="re78")
mat$tab
# imbalance
eval.match(LL$treated, LL, drop=todrop, breaks=mybr, weights=mat$w)
}
\keyword{ datagen }
